@@ -1,6 +1,7 @@
+# frozen_string_literal: false
 #   multi.rb -
 #   	$Release Version: 0.9.6$
-#   	$Revision: 38358 $
+#   	$Revision$
 #   	by Keiju ISHITSUKA(keiju@ruby-lang.org)
 #
 # --
@@ -8,33 +9,33 @@
 #
 #
 
-require "irb/cmd/nop.rb"
-require "irb/ext/multi-irb"
+require_relative "nop"
+require_relative "../ext/multi-irb"
 
 # :stopdoc:
 module IRB
   module ExtendCommand
-    class IrbCommand<Nop
+    class IrbCommand < Nop
       def execute(*obj)
-	IRB.irb(nil, *obj)
+        IRB.irb(nil, *obj)
       end
     end
 
-    class Jobs<Nop
+    class Jobs < Nop
       def execute
-	IRB.JobManager
+        IRB.JobManager
       end
     end
 
-    class Foreground<Nop
+    class Foreground < Nop
       def execute(key)
-	IRB.JobManager.switch(key)
+        IRB.JobManager.switch(key)
       end
     end
 
-    class Kill<Nop
+    class Kill < Nop
       def execute(*keys)
-	IRB.JobManager.kill(*keys)
+        IRB.JobManager.kill(*keys)
       end
     end
   end
