@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("3.0.") or
-    raise "ruby lib version (3.0.2) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (3.0.3) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.0/mips64-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
   CONFIG["MINOR"] = "0"
-  CONFIG["TEENY"] = "2"
-  CONFIG["PATCHLEVEL"] = "107"
-  CONFIG["INSTALL"] = '/pobj/ruby-3.0.2/bin/install -c'
+  CONFIG["TEENY"] = "3"
+  CONFIG["PATCHLEVEL"] = "157"
+  CONFIG["INSTALL"] = '/pobj/ruby-3.0.3/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)30"
@@ -95,7 +95,7 @@ module RbConfig
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
   CONFIG["strict_warnflags"] = "-std=gnu99"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wmissing-noreturn -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens"
+  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdivision-by-zero -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wshorten-64-to-32 -Wwrite-strings -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wunused-variable -Wextra-tokens"
   CONFIG["debugflags"] = "-ggdb3"
   CONFIG["optflags"] = "-O3"
   CONFIG["NULLCMD"] = ":"
@@ -147,9 +147,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/pobj/ruby-3.0.2/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/pobj/ruby-3.0.2/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/pobj/ruby-3.0.2/bin/install -c -s -m 755"
+  CONFIG["INSTALL_DATA"] = "/pobj/ruby-3.0.3/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/pobj/ruby-3.0.3/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/pobj/ruby-3.0.3/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["DLLWRAP"] = ""
@@ -157,7 +157,7 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 11.1.0\nTarget: mips64-unknown-openbsd7.0\nThread model: posix\nInstalledDir: /usr/bin"
+  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 13.0.0\nTarget: mips64-unknown-openbsd7.1\nThread model: posix\nInstalledDir: /usr/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["MJIT_CC"] = "/usr/bin/cc -fdeclspec"
   CONFIG["CSRCFLAG"] = ""
@@ -184,18 +184,18 @@ module RbConfig
   CONFIG["AS"] = "as"
   CONFIG["AR"] = "ar"
   CONFIG["CC"] = "cc -fdeclspec"
-  CONFIG["target_os"] = "openbsd7.0"
+  CONFIG["target_os"] = "openbsd7.1"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "mips64"
-  CONFIG["target"] = "mips64-unknown-openbsd7.0"
-  CONFIG["host_os"] = "openbsd7.0"
+  CONFIG["target"] = "mips64-unknown-openbsd7.1"
+  CONFIG["host_os"] = "openbsd7.1"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "mips64"
-  CONFIG["host"] = "mips64-unknown-openbsd7.0"
-  CONFIG["build_os"] = "openbsd7.0"
+  CONFIG["host"] = "mips64-unknown-openbsd7.1"
+  CONFIG["build_os"] = "openbsd7.1"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "mips64"
-  CONFIG["build"] = "mips64-unknown-openbsd7.0"
+  CONFIG["build"] = "mips64-unknown-openbsd7.1"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
